#[repr(usize)]
pub enum Opcode {
Show 13 variants ElapsedMs, SleepMs, RecalculateSleep, SuspendResume, PingWdt, GetVersion, LockMutex, UnlockMutex, WaitForCondition, NotifyCondition, FreeMutex, FreeCondition, InvalidCall,
}
Do not modify the discriminants in this structure. They are used in libstd directly.

Variants



ElapsedMs

Get the elapsed time in milliseconds



SleepMs

Sleep for the specified numer of milliseconds



RecalculateSleep

Recalculate the sleep time



SuspendResume

Suspend/resume callback



PingWdt

force a WDT update



GetVersion

Return the version string of Xous. We bury it here because this is a small, lightweight server we can rebuild on every run.



LockMutex

Lock the given Mutex, blocking if it is already locked.

Arguments

arg1: An integer of some sort, such as the address of the Mutex



UnlockMutex

Unlock the given Mutex

Arguments

arg1: An integer of some sort, such as the address of the Mutex



WaitForCondition

Wait for a given condition to be signalled

Arguments

arg1: An integer of some sort, such as the address of the Condvar arg2: The number of milliseconds to wait, or 0 to wait forever



NotifyCondition

Notify a condition

Arguments

arg1: An integer of some sort, such as the address of the Condvar arg2: The number of conditions to notify



FreeMutex

Free a Mutex

This call will free a Mutex that was previously Locked or Unlocked. Doing so causes the Mutex to be unlocked.

Arguments

arg1: The integer that matches the Mutex value



FreeCondition

Free a Condition

This call will free a Condition that was previously waited upon. All pending threads will be forgotten.

Arguments

arg1: The integer that matches the Condition value



InvalidCall

Invalid call – an error occurred decoding the opcode